@@ -13,7 +13,7 @@
 ##############################################################################
 """Basic components support
 
-$Id: registry.py 69947 2006-09-03 18:45:51Z srichter $
+$Id: registry.py 76703 2007-06-14 23:44:49Z rossp $
 """
 
 import types
@@ -277,7 +277,7 @@ class Components(object):
 
 
         self._subscription_registrations[:] = new
-        self.adapters.unsubscribe(required, provided)
+        self.adapters.unsubscribe(required, provided, factory)
 
         zope.event.notify(interfaces.Unregistered(
             SubscriptionRegistration(self, required, provided, name,
